# OpenBB Fixed Income Extension

This extension provides fixed income data for the OpenBB Platform.

Features of the Fixed Income extension include information on government bonds and central bank rates.

## Installation

To install the extension, run the following command in this folder:

```bash
pip install openbb-fixedincome
```

Documentation available [here](https://docs.openbb.co/platform/developer_guide/contributing).
